@@ -1,9 +1,9 @@
 package Acme::CPANModules::PortedFrom::Ruby;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-12-27'; # DATE
+our $DATE = '2021-02-05'; # DATE
 our $DIST = 'Acme-CPANModules-PortedFrom-Ruby'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our $LIST = {
     summary => "Modules/applications that are ported from (or inspired by) ".
@@ -29,6 +29,19 @@ _
             #ruby_package => undef',
             tags => ['web'],
         },
+        {
+            module => 'Plack',
+            ruby_package => 'rack',
+            tags => ['web'],
+            description => <<'_',
+
+From Plack's documentation: "Plack is like Ruby's Rack or Python's Paste for
+WSGI." Plack and PSGI was created by MIYAGAWA in 2009 and is inspired by both
+Python's WSGI specification (hence the dual specification-implementation split)
+and Plack (hence the name).
+
+_
+        },
     ],
 };
 
@@ -47,7 +60,7 @@ Acme::CPANModules::PortedFrom::Ruby - Modules/applications that are ported from
 
 =head1 VERSION
 
-This document describes version 0.004 of Acme::CPANModules::PortedFrom::Ruby (from Perl distribution Acme-CPANModules-PortedFrom-Ruby), released on 2020-12-27.
+This document describes version 0.005 of Acme::CPANModules::PortedFrom::Ruby (from Perl distribution Acme-CPANModules-PortedFrom-Ruby), released on 2021-02-05.
 
 =head1 DESCRIPTION
 
@@ -63,6 +76,14 @@ If you know of others, please drop me a message.
 
 =item * L<HTTP::Server::Brick>
 
+=item * L<Plack>
+
+From Plack's documentation: "Plack is like Ruby's Rack or Python's Paste for
+WSGI." Plack and PSGI was created by MIYAGAWA in 2009 and is inspired by both
+Python's WSGI specification (hence the dual specification-implementation split)
+and Plack (hence the name).
+
+
 =back
 
 =head1 FAQ
@@ -121,7 +142,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
